# PyTorch Lightning Spells

[![CircleCI](https://circleci.com/gh/veritable-tech/pytorch-lightning-spells/tree/master.svg?style=svg)](https://circleci.com/gh/veritable-tech/pytorch-lightning-spells/tree/master) [![Documentation Status](https://readthedocs.org/projects/pytorch-lightning-spells/badge/?version=latest)](https://pytorch-lightning-spells.readthedocs.io/en/latest/?badge=latest)

Some useful plugins for [PyTorch Lightning](https://github.com/PyTorchLightning/pytorch-lightning).

[Documentation](https://pytorch-lightning-spells.readthedocs.io/)

**IMPORTANT NOTICE**: the current release is compatible with PyTorch Lightning version `1.1.3` to `1.4.0`. There is ongoing work on [the pl_1_5 branch](https://github.com/veritable-tech/pytorch-lightning-spells/tree/pl_1_5) to make this library compatible with PyTorch Lightning version `1.5.x`.

## Installation

```bash
pip install pytorch-lightning-spells
```

or the latest in the main branch:

```bash
pip install https://github.com/veritable-tech/pytorch-lightning-spells/archive/master.zip
```
